@@ -32,4 +32,4 @@ if __name__ == '__main__':
     try:
         CLI.Command(main)(sys.argv[1:]).run()
     except PrettyException as e:
-        print.pretty(e)
+        print.pretty(e, pad=1)
