@@ -1,4 +1,4 @@
-from print_ext import print, Table, pretty, Text
+from print_ext import print, Table, pretty, Printer
 from docstring_parser import parse as docstring_parse
 
 
@@ -14,10 +14,7 @@ class CmdDoc():
         return self.doc.short_description
 
     def pretty_full(self):
-        f = Text()
-        if self.doc.short_description: f('\bem$',self.doc.short_description,'\v\v')
-        if self.doc.long_description: f(self.doc.long_description,'\v')
-        return f
-
-
-
+        p = Printer()
+        if self.doc.short_description: p('\bem$',self.doc.short_description, pad=(0,1))
+        if self.doc.long_description: p(self.doc.long_description, pad=-1)
+        return p
